@@ -134,8 +134,8 @@ CLI_PARAMETERS_HELP = {
         'config': "Comma separated list of key/value pairs to temporarily override the current DSO application configurations. It takes effect only while executing the command and does not have any lasting effect on the DSO application configuration or subsequent command executions.",
         'query': "Customize output using JMESPath query language.",
         'query_all': "Include all the available fields in the ouput.",
-        'global_context': "Use the global context.",
-        'project_context': "Use the project context.",
+        'global_scope': "Use the global context.",
+        'project_scope': "Use the project context.",
 
     },
     'parameter': {
