@@ -147,7 +147,6 @@ class ConfigManager:
 
     def dict_to_config_string(self, dic):
         flat = flatten_dict(dic)
-        print(flat)
         return reduce(lambda x, y: f"{x[0]}={x[1]},{y[0]}={y[1]}", flat)
 
 
@@ -173,7 +172,7 @@ class ConfigManager:
             Logger.warn("Switched to the global context.")
         elif context == 'project':
             _config['application'] = 'default'
-            Logger.warn(f"Switched to the project context '{self.project}'.")
+            Logger.warn(f"Switched to project context '{self.project}'.")
         elif context == 'application':
             pass
         return merge_dicts(self.config_string_to_dict(config_overrides_string), _config)
@@ -243,7 +242,7 @@ class ConfigManager:
             result  = os.getenv('DSO_APPLICATION') or 'default'
         if self.project == 'default':
             if not result == 'default':
-                # Logger.warn(f"Switched to the project context '{self.project}' from the application context '{result}'.")
+                # Logger.warn(f"Switched to project context '{self.project}' from the application context '{result}'.")
                 Logger.debug(f"The application context '{result}' was reset because the global context is being used.")
                 result = 'default'
         return result.lower()
