@@ -13,7 +13,7 @@ from dsocli.aws_utils import *
 
 
 _default_spec = {
-    'prefix': '/dso/v1'
+    'prefix': '/dso/v1/parameters'
 }
 
 def get_default_spec():
@@ -37,7 +37,7 @@ class AwsSsmParameterProvider(ParameterProvider):
 ###--------------------------------------------------------------------------------------------
 
     def get_prefix(self):
-        return Configs.parameter_spec('prefix') + '/parameters'
+        return Configs.parameter_spec('prefix')
 
 ###--------------------------------------------------------------------------------------------
 
