@@ -13,7 +13,7 @@ from dsocli.aws_utils import *
 
 
 _default_spec = {
-    'prefix': '/dso/v1'
+    'prefix': '/dso/v1/secrets'
 }
 
 def get_default_spec():
@@ -38,7 +38,7 @@ class AwsSsmSecretProvider(SecretProvider):
 ###--------------------------------------------------------------------------------------------
 
     def get_prefix(self):
-        return Configs.parameter_spec('prefix') + '/parameters'
+        return Configs.secret_spec('prefix')
 
 ###--------------------------------------------------------------------------------------------
 
