@@ -15,13 +15,24 @@ class ProviderBase():
 
 class StoreProvider(ProviderBase):
 
-    def validate_key(self, key):
-        Logger.debug(f"Validating: key={key}")
-        pattern = self.get_key_validator()
-        if not re.match(pattern, key):
-            raise DSOException(MESSAGES['InvalidKey'].format(key, pattern))
+    # def validate_key(self, key):
+    #     Logger.debug(f"Validating: key={key}")
+    #     pattern = self.get_key_validator()
+    #     if not re.match(pattern, key):
+    #         raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
 
-    def get_key_validator(self, key):
+    # def get_key_validator(self, key):
+    #     raise NotImplementedError()
+
+    def list(self):
+        raise NotImplementedError()
+    def add(self):
+        raise NotImplementedError()
+    def delete(self):
+        raise NotImplementedError()
+    def get(self):
+        raise NotImplementedError()
+    def history(self):
         raise NotImplementedError()
 
 
